Calculates a Mahalanobis distance for every row of a set of outcome variables (Mahalanobis, 1936 tools:::Rd_expr_doi("10.1007/s13171-019-00164-5")). The conditional Mahalanobis distance is calculated using a conditional covariance matrix (i.e., a covariance matrix of the outcome variables after controlling for a set of predictors). Plotting the output of the cond_maha() function can help identify which elements of a profile are unusual after controlling for the predictors.
Maintainer: W. Joel Schneider w.joel.schneider@gmail.com (ORCID)
Authors:
Feng Ji fengji@berkeley.edu