dCM = Conditional Mahalanobis distance
dCM_df = Degrees of freedom for the conditional Mahalanobis distance
dCM_p = A proportion that indicates how unusual this profile is
compared to profiles with the same independent variable values. For example,
if dCM_p = 0.88, this profile is more unusual than 88 percent of profiles
after controlling for the independent variables.
dM_dep = Mahalanobis distance of just the dependent variables
dM_dep_df = Degrees of freedom for the Mahalanobis distance of
the dependent variables
dM_dep_p = Proportion associated with the Mahalanobis distance
of the dependent variables
dM_ind = Mahalanobis distance of just the independent variables
dM_ind_df = Degrees of freedom for the Mahalanobis distance of
the independent variables
dM_ind_p = Proportion associated with the Mahalanobis distance
of the independent variables
v_dep = Dependent variable names
v_ind = Independent variable names
v_ind_singular = Independent variables that can be perfectly
predicted from the dependent variables (e.g., composite scores)
v_ind_nonsingular = Independent variables that are not perfectly
predicted from the dependent variables
data = data used in the calculations
d_ind = independent variable data
d_inp_p = Assuming normality, cumulative distribution function
of the independent variables
d_dep = dependent variable data
d_dep_predicted = predicted values of the dependent variables
d_dep_deviations = d_dep - d_dep_predicted (i.e., residuals of
the dependent variables)
d_dep_residuals_z = standardized residuals of the dependent
variables
d_dep_cp = conditional proportions associated with
standardized residuals
d_dep_p = Assuming normality, cumulative distribution function
of the dependent variables
R2 = Proportion of variance in each dependent variable explained
by the independent variables
zSEE = Standardized standard error of the estimate
for each dependent variable
SEE = Standard error of the estimate for each dependent variable
ConditionalCovariance = Covariance matrix of the dependent
variables after controlling for the independent variables
distance_reduction = 1 - (dCM / dM_dep) (Degree to which the
independent variables decrease the Mahalanobis distance of the dependent
variables. Negative reductions mean that the profile is more unusual
after controlling for the independent variables. Returns 0
if dM_dep is 0.)
variability_reduction = 1 - sum((X_dep - predicted_dep) ^ 2) / sum((X_dep - mu_dep) ^ 2) (Degree to which the independent variables
decrease the variability the dependent variables (X_dep).
Negative reductions mean that the profile is more variable after
controlling for the independent variables. Returns 0 if X_dep == mu_dep)
mu = Variable means
sigma = Variable standard deviations
d_person = Data frame consisting of Mahalanobis distance data for
each person
d_variable = Data frame consisting of variable characteristics
label = label slot